@@ -28,14 +28,14 @@
 //!
 //! ```toml
 //! [dependencies]
-//! iced-x86 = "1.12.0"
+//! iced-x86 = "1.13.0"
 //! ```
 //!
 //! Or to customize which features to use:
 //!
 //! ```toml
 //! [dependencies.iced-x86]
-//! version = "1.12.0"
+//! version = "1.13.0"
 //! default-features = false
 //! # See below for all features
 //! features = ["std", "decoder", "masm"]
@@ -1171,7 +1171,7 @@
 //! Bumping the minimum supported version of `rustc` is considered a minor breaking change. The minor version of iced-x86 will be incremented.
 
 #![doc(html_logo_url = "https://raw.githubusercontent.com/icedland/iced/master/logo.png")]
-#![doc(html_root_url = "https://docs.rs/iced-x86/1.12.0")]
+#![doc(html_root_url = "https://docs.rs/iced-x86/1.13.0")]
 #![allow(unknown_lints)]
 #![warn(absolute_paths_not_starting_with_crate)]
 #![warn(anonymous_parameters)]
@@ -1192,6 +1192,8 @@
 #![warn(unused_must_use)]
 #![warn(unused_qualifications)]
 #![warn(unused_results)]
+#![allow(clippy::bool_assert_comparison)]
+#![allow(clippy::branches_sharing_code)]
 #![allow(clippy::cast_lossless)]
 #![allow(clippy::collapsible_else_if)]
 #![allow(clippy::collapsible_if)]
@@ -1205,6 +1207,7 @@
 #![allow(clippy::type_complexity)]
 #![allow(clippy::upper_case_acronyms)]
 #![allow(clippy::wrong_self_convention)]
+#![warn(clippy::cloned_instead_of_copied)]
 #![warn(clippy::dbg_macro)]
 #![warn(clippy::debug_assert_with_mut_call)]
 #![warn(clippy::default_trait_access)]
@@ -1227,12 +1230,11 @@
 #![warn(clippy::print_stderr)]
 #![warn(clippy::print_stdout)]
 #![warn(clippy::rc_buffer)]
-#![warn(clippy::redundant_closure_for_method_calls)]
 #![warn(clippy::redundant_closure)]
+#![warn(clippy::redundant_closure_for_method_calls)]
 #![warn(clippy::same_functions_in_if_condition)]
 #![warn(clippy::todo)]
 #![warn(clippy::unimplemented)]
-#![warn(clippy::unnested_or_patterns)]
 #![warn(clippy::unreadable_literal)]
 #![warn(clippy::unused_self)]
 #![warn(clippy::unwrap_in_result)]
